# -*- coding: utf-8 -*-

from django.contrib import admin
from django.utils.translation import ugettext as _
from image_cropping import ImageCroppingMixin

from jmb.jadmin.options import JumboModelAdmin

from acomea.engagement.forms import CategoryAdminForm
from acomea.engagement.models import Package, FundExtra, ApplicazioneExtra, Category


class FundExtraAdmin(admin.StackedInline):
    model = FundExtra
    extra = 0


class ApplicazioneExtraAdmin(admin.StackedInline):
    model = ApplicazioneExtra
    extra = 0


class PackageAdmin(JumboModelAdmin):
    fieldsets = (
        (_('logs admin'), {
            'fields': ('creator', 'last_modifier'),
            'classes': ('collapse',)
        }),
        (_("Ordering"), {
            'fields': ('ordering',),
            'classes': ('collapse',)
        }),
        (_('info'), {
            'fields': (
                'category',
                'period',
                'timing',
                'description',
                'historical_series',
            )}),
    )

    list_display = (
        'get_status_display', 'category', 'period', 'get_edit_icon', 'get_delete_icon',
    )
    save_on_top = True
    inlines = [FundExtraAdmin, ApplicazioneExtraAdmin]


class CategoryAdmin(ImageCroppingMixin, JumboModelAdmin):
    fieldsets = (
        (_("Ordering"), {
            'fields': ('ordering',),
            'classes': ('collapse',)
        }),
        (_('info'), {
            'fields': (
                'name', 'slug',
                'subtitle',
                'home_description',
                'description',
                'tile',
                'tile_cropping',
                'cover',
                'cover_cropping',
                'cover_cropping_box',
                'icon',
                'icon_cropping',
            )}),
    )
    list_display = (
        'name', 'get_status_display', 'get_edit_icon', 'get_delete_icon',
    )
    form = CategoryAdminForm
    prepopulated_fields = {'slug': ('name',)}

    save_on_top = True


admin.site.register(Package, PackageAdmin)
admin.site.register(Category, CategoryAdmin)
admin.site.register(FundExtra)
admin.site.register(ApplicazioneExtra)
