# -*- coding: utf-8 -*-

from django.db import models
from django.utils.translation import ugettext as _
from django.conf import settings

from cms.models.pluginmodel import CMSPlugin

from imagekit.models import ProcessedImageField
from pilkit.processors import ResizeToFit
from image_cropping import ImageRatioField
from easy_thumbnails.exceptions import InvalidImageFormatError
from easy_thumbnails.files import get_thumbnailer

from jmb.core.db.models import HTMLFieldTinyMCE


class EngagementTitleSettings(CMSPlugin):
    TEMPLATES = (
       ("engagement/cms_plugins/title_template.html", "title template"),
    )
    template_name = models.CharField(
       max_length=100,
       choices=TEMPLATES,
       default="engagement/cms_plugins/title_template.html"
    )

    def __unicode__(self):
        return "engagement title"

    class Meta:
        app_label = "engagement"


class EngagementTileSettings(CMSPlugin):
    TEMPLATES = (
       ("engagement/cms_plugins/tile_template.html", "tile template"),
    )
    template_name = models.CharField(
       max_length=100,
       choices=TEMPLATES,
       default="engagement/cms_plugins/tile_template.html"
    )

    def __unicode__(self):
        return "engagement tile"

    class Meta:
        app_label = "engagement"


class DataSettings(CMSPlugin):
    TEMPLATES = (
       ("engagement/cms_plugins/data_template.html", "data template"),
    )
    template_name = models.CharField(
       max_length=100,
       choices=TEMPLATES,
       default="engagement/cms_plugins/data_template.html"
    )

    def __unicode__(self):
        return "engagement data"

    class Meta:
        app_label = "engagement"


class EngagementNavSettings(CMSPlugin):
    TEMPLATES = (
       ("engagement/cms_plugins/nav_template.html", "nav template"),
    )
    template_name = models.CharField(
       max_length=100,
       choices=TEMPLATES,
       default="engagement/cms_plugins/nav_template.html"
    )

    def __unicode__(self):
        return "engagement nav"

    class Meta:
        app_label = "engagement"


class EngagementHomepageSettings(CMSPlugin):
    TEMPLATES = (
       ("engagement/cms_plugins/homepage_template.html", "homepage template"),
    )
    title = models.CharField(
        _("title"),
        max_length=255,
        blank=True, null=True,
        help_text=_("homepage title")
    )
    subtitle = models.CharField(
        _("subtitle"),
        max_length=255,
        blank=True, null=True,
        help_text=_("homepage subtitle")
    )
    cover = ProcessedImageField(
        processors=[ResizeToFit(width=900)],
        upload_to=settings.ENGAGEMENT_COVER_UPLOAD_TO,
        format='JPEG',
        options={'quality': 100},
        help_text=_("category cover"),
        blank=True, null=True,
        verbose_name=_("cover")
    )
    cover_cropping = ImageRatioField(
        'cover',
        '850x197',
        size_warning=True
    )
    body = HTMLFieldTinyMCE(
        blank=True, null=True,
        verbose_name=_("Body"),
        help_text=_("body"),
    )
    template_name = models.CharField(
       max_length=100,
       choices=TEMPLATES,
       default="engagement/cms_plugins/homepage_template.html"
    )

    post_body = HTMLFieldTinyMCE(
        blank=True, null=True,
        verbose_name=_("post body"),
        help_text=_("body at the end of template"),
    )

    @property
    def cover_url(self):
        try:
            return get_thumbnailer(self.cover).get_thumbnail({
                    'size': (850, 197),
                    'box': self.cover_cropping,
                    'crop': True,
                    'detail': True,
                }).url
        except (InvalidImageFormatError, AttributeError):
            return ""

    def __unicode__(self):
        return "engagement homepage"

    class Meta:
        app_label = "engagement"
