var historicalSettings = {
    chart: {
        zoomType: 'x'
    },
    title: {
        text: 'E se ci avessi pensato prima?'
    },
    subtitle: {
        text: document.ontouchstart === undefined ?
            'Andamento di 100 mila euro investiti' : 'Pinch the chart to zoom in'
    },
    xAxis: {
        type: 'datetime'
    },
    yAxis: {
        title: {
            text: ''
        }
    },
    legend: {
        enabled: false
    },
    credits: {
        enabled: false
    },
    plotOptions: {
        series: {
            fillColor: 'rgba(240,240,240,0.2)'
        }
    },
    series: [{
        type: 'area',
        name: 'EUR',
        data: []
    }]
};

var pieSettings = {
    chart: {
        plotBackgroundColor: null,
        plotBorderWidth: null,
        plotShadow: false,
        type: 'pie',
        height: 200,
    },
    title: {text: ''},
    tooltip: {
        pointFormat: '{series.name}: <b>{point.percentage:.1f}%</b>'
    },
    plotOptions: {
        pie: {
            allowPointSelect: true,
            cursor: 'pointer',
            dataLabels: {enabled: false}
        }
    },
    credits: {
        enabled: false
    },
    series: [{
        name: 'Fondo',
        colorByPoint: true,
        data: [],
    }]
};

var Category = function (data) {
    this.name = data.name;
    this.slug = data.slug;
    this.subtitle = data.subtitle;
    this.home_description = data.home_description;
    this.description = data.description;
    this.tile_url = data.tile_url;
    this.cover_url = data.cover_url;
    this.cover_box_url = data.cover_box_url;
    this.icon_url = data.icon_url;
    this.packages = [];
    for (var i in data.packages) {
        this.packages.push(new Package(data.packages[i]));
    }
};

var Package = function (data) {
    this.period = data.period;
    this.timing = data.timing;
    this.description = data.description;
    this.id = data.id;
    this.funds = [];
    for (var i in data.fund_extras) {
        this.funds.push(
            new Fund(data.fund_extras[i])
        );
    }
    this.applicazione = [];
    for (i in data.applicazione_extras) {
        this.applicazione.push(
            new Applicazione(data.applicazione_extras[i])
        );
    }
    this.historicalSeries = [];
    if (data.historical_series) {
        this.getHistoricalData(
            JSON.parse(data.historical_series)
        );
    }
};
Package.prototype.getGraphData = function () {
    var graphData = [];
    for (var i in this.funds) {
        graphData.push(
            {
                name: this.funds[i].fundShortName,
                y: this.funds[i].fundPercent,
                color: this.funds[i].fundColor
            }
        );
    }
    return graphData;
};
Package.prototype.getHistoricalData = function (data) {
    for (var key in data) {
        var serie = {
            type: 'area',
            name: key,
            data: []
        };
        for (var i in data[key]) {
            var entry = [];
            var date = data[key][i][0];
            date = date.split(',');
            var year = parseInt(date[0]);
            var month = parseInt(date[1]) - 1; // months start at 0 for January, 1 for February etc.
            var day = parseInt(date[2]);
            entry.push(Date.UTC(year, month, day));
            entry.push(data[key][i][1]);
            serie.data.push(entry);
        }
        this.historicalSeries.push(serie);
    }
};

var Fund = function (data) {
    this.fundShortName = data.fund_short_name;
    this.fundDescription = data.fund_description;
    this.fundPercent = parseInt(data.fund_percent_number);
    this.fundColor = data.fund_color;
};

var Applicazione = function (data) {
    this.applicazioneshortName = data.applicazione_short_name;
    this.applicazioneDescription = data.applicazione_description;
};

var Engagement = function (slug, period) {
    var self = this;

    // Istanzio il grafico a torta
    (function () {
        $('#package-chart').highcharts(pieSettings);
        self.graph = $('#package-chart').highcharts();
    })();

    // Istanzio il grafico della serie storica
    (function () {
        $('#package-historical').highcharts(historicalSettings);
        self.historical = $('#package-historical').highcharts();
    })();

    self.categories = ko.observableArray([]);

    // carico il json contenente i dati su categorie e pacchetti
    var data = $('#engagement-data').data('engagement');

    // Istanzio le categorie e le aggiungo all'observableArray
    for (var i in data) {
        self.categories.push(new Category(data[i]));
    }
    self.selectedCategory = ko.observable();
    self.selectedPeriod = ko.observable(0);
    self.showHomepage = ko.computed(function () {
        return !self.selectedCategory();
    });

    self.hash = ko.computed(function () {
        var hash = '';
        if (self.selectedCategory()) {
            hash = '/' + self.selectedCategory().slug + '/';
            if (self.selectedPackage()) {
                hash = hash + self.selectedPeriod() + '/';
            }
        }
        return hash;
    });
    self.fullpath = ko.computed(function () {
        return location.pathname + "#" + self.hash();
    });

    // build computed url for facebook login
    self.socialRedirectUrl = ko.computed(function () {
        var engagement_redirect_url = $('#login-social').data('engagement-redirect-url');
        var group_id = $('#group').data('group-id');
        return engagement_redirect_url + '?redirect=' + self.fullpath() + '&group_id=' + group_id;
    });
    self.FBLogin = function () {
        return allauth.facebook.login(self.socialRedirectUrl());
    };
    self.googleLogin = function () {
        var next_url = '/accounts/google/login/?next=' + self.socialRedirectUrl();
        window.location.href = next_url;

    };

    self.hash.subscribe(function (hash) {
        var obj = {
            slug: self.selectedCategory().slug,
            period: self.selectedPeriod()
        };
        history.pushState(obj, "", location.pathname + "#" + self.hash());
    });

    self.selectedPackage = ko.computed(function () {
        if (self.selectedCategory()) {
            for (var k in self.selectedCategory().packages) {
                if (self.selectedCategory().packages[k].period == self.selectedPeriod()) {
                    return self.selectedCategory().packages[k];
                }
            }
            return null;
        }
    }, this);

    self.selectedPackage.subscribe(function (pack) {
        if (self.selectedCategory()) {
            var data = [];
            var hist = [];
            if (pack) {
                data = pack.getGraphData();
                hist = pack.historicalSeries;
            }
            if (self.graph && self.historical) {
                self.graph.series[0].setData(data);
                for (var i = self.historical.series.length - 1; i >= 0; i--) {
                    self.historical.series[i].remove();
                }
                for (i in hist) {
                    self.historical.addSeries(hist[i]);
                }
            }
        }
    });

    self.setCategory = function (category) {
        if (category !== self.selectedCategory()) {
            self.selectedCategory(category);
            // add category group to user
            self.addGroupToUser(category);
            $('#drawerExample').removeClass('open');
        }
    };

    self.selectSlice = function (index, data, event) {
        self.graph.series[0].data[index()].select();
    };
    self.addGroupToUser = function (category) {
        $.ajax({
            type: "POST",
            url: '/acomea_engagement/ajax_set_groups/',
            dataType: 'json',
            data: {
                category_slug: category.slug
            }
        });
    };

};


var engagement;
var hash;

var getCategoryBySlug = function (slug) {
    for (i = 0; i < engagement.categories().length; i++) {
        if (engagement.categories()[i].slug === slug) {
            return engagement.categories()[i];
        }
    }
};

document.addEventListener('DOMContentLoaded', function () {
    engagement = new Engagement();
    $('body').popover({
        placement: 'left',
        trigger: 'focus',
        selector: '[data-toggle="popover"]'
    });

    hash = location.hash.split('/');

    if (hash[1]) {
        engagement.selectedCategory(getCategoryBySlug(hash[1]));
    }
    if (hash[2] && engagement.selectedCategory()) {
        engagement.selectedPeriod(parseInt(hash[2]));
    }

    engagement.slider = $('#period-slider').bootstrapSlider({
        ticks: [0, 1, 2],
        ticks_labels: [
            "<img src='/static/engagement/img/time1.png'>",
            "<img src='/static/engagement/img/time2.png'>",
            "<img src='/static/engagement/img/time3.png'>"
        ],
        min: 0,
        max: 2,
        step: 1,
        value: engagement.selectedPeriod(),
        tooltip: "hide"
    });
    ko.applyBindings(engagement);

    window.onpopstate = function (event) {
        if (event.state.slug) {
            engagement.selectedCategory(getCategoryBySlug(event.state.slug));
            if (engagement.selectedCategory && event.state.period) {
                engagement.selectedPeriod(parseInt(event.state.period));
            }
        }
    };
    $(".showcase-thumb figure").on('mouseenter mouseleave', hoverEffect);


    function hoverEffect() {
        $(this).find('img').toggleClass('hover');
        $(this).find('h1').toggleClass('text-hover');
        if ($(this).has('.body').length) {
            $(this).find('figcaption').toggleClass('overlay-hover');
        }
        $(this).find('.body').fadeToggle('fast');
    }

    function getCookie(name) {
        var cookieValue = null;
        if (document.cookie && document.cookie !== '') {
            var cookies = document.cookie.split(';');
            for (var i = 0; i < cookies.length; i++) {
                var cookie = jQuery.trim(cookies[i]);
                // Does this cookie string begin with the name we want?
                if (cookie.substring(0, name.length + 1) === (name + '=')) {
                    cookieValue = decodeURIComponent(cookie.substring(name.length + 1));
                    break;
                }
            }
        }
        return cookieValue;
    }

    var csrftoken = getCookie('csrftoken');

    function csrfSafeMethod(method) {
        // these HTTP methods do not require CSRF protection
        return (/^(GET|HEAD|OPTIONS|TRACE)$/.test(method));
    }

    $.ajaxSetup({
        beforeSend: function (xhr, settings) {
            if (!csrfSafeMethod(settings.type) && !this.crossDomain) {
                xhr.setRequestHeader("X-CSRFToken", csrftoken);
            }
        }
    });
});
